@@ -27,7 +27,7 @@ fragment metadataEntryFragment on EventMetadataEntry {
     floatValue
   }
   ... on EventIntMetadataEntry {
-    intValue
+    intRepr
   }
   ... on EventJsonMetadataEntry {
     jsonString
@@ -48,6 +48,14 @@ fragment metadataEntryFragment on EventMetadataEntry {
   ... on EventUrlMetadataEntry {
     url
   }
+  ... on EventPipelineRunMetadataEntry  {
+    runId
+  }
+  ... on EventAssetMetadataEntry  {
+    assetKey {
+      path
+    }
+  }
 }
 
 fragment stepEventFragment on StepEvent {
@@ -157,14 +165,26 @@ fragment stepEventFragment on StepEvent {
 MESSAGE_EVENT_FRAGMENTS = (
     """
 fragment messageEventFragment on MessageEvent {
+  __typename
   runId
   message
   timestamp
   level
   eventType
   ...stepEventFragment
-  ... on PipelineInitFailureEvent {
-    initError: error {
+  ... on StepMaterializationEvent {
+    materialization {
+      label
+      description
+      metadataEntries {
+        __typename
+        ...metadataEntryFragment
+      }
+    }
+  }
+  ... on ExecutionStepFailureEvent {
+    stepKey
+    error {
       ...errorFragment
     }
   }
@@ -185,30 +205,10 @@ subscription subscribeTest($runId: ID!) {
         runId
       }
       messages {
-        __typename
         ...messageEventFragment
-
-        # only include here because unstable between runs
-        ... on StepMaterializationEvent {
-          materialization {
-            label
-            description
-            metadataEntries {
-              __typename
-              ...metadataEntryFragment
-            }
-          }
-        }
-
-        ... on ExecutionStepFailureEvent {
-          stepKey
-          error {
-            ...errorFragment
-          }
-        }
       }
+      hasMorePastEvents
     }
-
     ... on PipelineRunLogsSubscriptionFailure {
       missingRunId
       message
@@ -219,6 +219,22 @@ subscription subscribeTest($runId: ID!) {
 """
 )
 
+RUN_EVENTS_QUERY = (
+    MESSAGE_EVENT_FRAGMENTS
+    + """
+query pipelineRunEvents($runId: ID!, $after: Cursor) {
+  pipelineRunOrError(runId: $runId) {
+    __typename
+    ... on PipelineRun {
+      events(after: $after) {
+        ...messageEventFragment
+      }
+    }
+  }
+}
+  """
+)
+
 LAUNCH_PIPELINE_EXECUTION_MUTATION = (
     ERROR_FRAGMENT
     + """
@@ -233,7 +249,7 @@ mutation($executionParams: ExecutionParams!) {
       stepKey
       invalidOutputName
     }
-    ... on LaunchPipelineRunSuccess {
+    ... on LaunchRunSuccess {
       run {
         runId
         pipeline {
@@ -255,7 +271,7 @@ mutation($executionParams: ExecutionParams!) {
       preset
       message
     }
-    ... on PipelineConfigValidationInvalid {
+    ... on RunConfigValidationInvalid {
       pipelineName
       errors {
         __typename
@@ -287,7 +303,7 @@ mutation($executionParams: ExecutionParams!) {
     ... on PythonError {
       ...errorFragment
     }
-    ... on LaunchPipelineRunSuccess {
+    ... on LaunchRunSuccess {
       run {
         runId
         status
@@ -308,7 +324,7 @@ mutation($executionParams: ExecutionParams!) {
       message
       pipelineName
     }
-    ... on PipelineConfigValidationInvalid {
+    ... on RunConfigValidationInvalid {
       pipelineName
       errors {
         __typename
