@@ -1,6 +1,7 @@
 from dagster import PipelineDefinition, check
 from dagster.config.validate import validate_config
 from dagster.core.definitions import create_run_config_schema
+from dagster.core.errors import DagsterRunNotFoundError
 from dagster.core.host_representation import PipelineSelector
 from dagster.core.storage.pipeline_run import PipelineRunsFilter
 from dagster.core.storage.tags import TagType, get_tag_type
@@ -20,7 +21,7 @@ def is_config_valid(pipeline_def, run_config, mode):
 
 
 def get_validated_config(pipeline_def, run_config, mode):
-    from ..schema.pipelines.config import GraphenePipelineConfigValidationInvalid
+    from ..schema.pipelines.config import GrapheneRunConfigValidationInvalid
 
     check.str_param(mode, "mode")
     check.inst_param(pipeline_def, "pipeline_def", PipelineDefinition)
@@ -31,7 +32,7 @@ def get_validated_config(pipeline_def, run_config, mode):
 
     if not validated_config.success:
         raise UserFacingGraphQLError(
-            GraphenePipelineConfigValidationInvalid.for_validation_errors(
+            GrapheneRunConfigValidationInvalid.for_validation_errors(
                 pipeline_def.get_external_pipeline(), validated_config.errors
             )
         )
@@ -40,15 +41,15 @@ def get_validated_config(pipeline_def, run_config, mode):
 
 
 def get_run_by_id(graphene_info, run_id):
-    from ..schema.errors import GraphenePipelineRunNotFoundError
-    from ..schema.pipelines.pipeline import GraphenePipelineRun
+    from ..schema.errors import GrapheneRunNotFoundError
+    from ..schema.pipelines.pipeline import GrapheneRun
 
     instance = graphene_info.context.instance
     run = instance.get_run_by_id(run_id)
     if not run:
-        return GraphenePipelineRunNotFoundError(run_id)
+        return GrapheneRunNotFoundError(run_id)
     else:
-        return GraphenePipelineRun(run)
+        return GrapheneRun(run)
 
 
 def get_run_tags(graphene_info):
@@ -65,23 +66,20 @@ def get_run_tags(graphene_info):
 @capture_error
 def get_run_group(graphene_info, run_id):
     from ..schema.errors import GrapheneRunGroupNotFoundError
-    from ..schema.pipelines.pipeline import GraphenePipelineRun
+    from ..schema.pipelines.pipeline import GrapheneRun
     from ..schema.runs import GrapheneRunGroup
 
     instance = graphene_info.context.instance
-    result = instance.get_run_group(run_id)
-
-    if result is None:
+    try:
+        result = instance.get_run_group(run_id)
+    except DagsterRunNotFoundError:
         return GrapheneRunGroupNotFoundError(run_id)
-    else:
-        root_run_id, run_group = result
-        return GrapheneRunGroup(
-            root_run_id=root_run_id, runs=[GraphenePipelineRun(run) for run in run_group]
-        )
+    root_run_id, run_group = result
+    return GrapheneRunGroup(root_run_id=root_run_id, runs=[GrapheneRun(run) for run in run_group])
 
 
 def get_runs(graphene_info, filters, cursor=None, limit=None):
-    from ..schema.pipelines.pipeline import GraphenePipelineRun
+    from ..schema.pipelines.pipeline import GrapheneRun
 
     check.opt_inst_param(filters, "filters", PipelineRunsFilter)
     check.opt_str_param(cursor, "cursor")
@@ -105,7 +103,7 @@ def get_runs(graphene_info, filters, cursor=None, limit=None):
     else:
         runs = instance.get_runs(cursor=cursor, limit=limit)
 
-    return [GraphenePipelineRun(run) for run in runs]
+    return [GrapheneRun(run) for run in runs]
 
 
 def get_runs_count(graphene_info, filters):
@@ -113,7 +111,7 @@ def get_runs_count(graphene_info, filters):
 
 
 def get_run_groups(graphene_info, filters=None, cursor=None, limit=None):
-    from ..schema.pipelines.pipeline import GraphenePipelineRun
+    from ..schema.pipelines.pipeline import GrapheneRun
     from ..schema.runs import GrapheneRunGroup
 
     check.opt_inst_param(filters, "filters", PipelineRunsFilter)
@@ -125,7 +123,7 @@ def get_run_groups(graphene_info, filters=None, cursor=None, limit=None):
 
     for root_run_id in run_groups:
         run_groups[root_run_id]["runs"] = [
-            GraphenePipelineRun(run) for run in run_groups[root_run_id]["runs"]
+            GrapheneRun(run) for run in run_groups[root_run_id]["runs"]
         ]
 
     return [
@@ -170,15 +168,15 @@ def get_execution_plan(graphene_info, selector, run_config, mode):
 
 @capture_error
 def get_stats(graphene_info, run_id):
-    from ..schema.pipelines.pipeline_run_stats import GraphenePipelineRunStatsSnapshot
+    from ..schema.pipelines.pipeline_run_stats import GrapheneRunStatsSnapshot
 
     stats = graphene_info.context.instance.get_run_stats(run_id)
     stats.id = "stats-{run_id}"
-    return GraphenePipelineRunStatsSnapshot(stats)
+    return GrapheneRunStatsSnapshot(stats)
 
 
 def get_step_stats(graphene_info, run_id, step_keys=None):
-    from ..schema.logs.events import GraphenePipelineRunStepStats
+    from ..schema.logs.events import GrapheneRunStepStats
 
     step_stats = graphene_info.context.instance.get_run_step_stats(run_id, step_keys)
-    return [GraphenePipelineRunStepStats(stats) for stats in step_stats]
+    return [GrapheneRunStepStats(stats) for stats in step_stats]
