@@ -4,15 +4,13 @@ from collections import namedtuple
 from dagster import check
 from dagster.core.host_representation import PipelineSelector
 from dagster.utils.error import serializable_error_info_from_exc_info
+from graphql.execution.base import ResolveInfo
 
 
 def check_permission(permission):
     def decorator(fn):
         def _fn(self, graphene_info, *args, **kwargs):  # pylint: disable=unused-argument
-            from dagster_graphql.schema.errors import GrapheneUnauthorizedError
-
-            if not graphene_info.context.has_permission(permission):
-                raise UserFacingGraphQLError(GrapheneUnauthorizedError())
+            assert_permission(graphene_info, permission)
 
             return fn(self, graphene_info, *args, **kwargs)
 
@@ -21,6 +19,13 @@ def check_permission(permission):
     return decorator
 
 
+def assert_permission(graphene_info: ResolveInfo, permission: str) -> None:
+    from dagster_graphql.schema.errors import GrapheneUnauthorizedError
+
+    if not graphene_info.context.has_permission(permission):
+        raise UserFacingGraphQLError(GrapheneUnauthorizedError())
+
+
 def capture_error(fn):
     def _fn(*args, **kwargs):
         from dagster_graphql.schema.errors import GraphenePythonError
@@ -29,7 +34,7 @@ def capture_error(fn):
             return fn(*args, **kwargs)
         except UserFacingGraphQLError as de_exception:
             return de_exception.error
-        except Exception:  # pylint: disable=broad-except
+        except Exception:
             return GraphenePythonError(serializable_error_info_from_exc_info(sys.exc_info()))
 
     return _fn
@@ -49,7 +54,7 @@ def pipeline_selector_from_graphql(data):
     return PipelineSelector(
         location_name=data["repositoryLocationName"],
         repository_name=data["repositoryName"],
-        pipeline_name=data["pipelineName"],
+        pipeline_name=data.get("pipelineName") or data.get("jobName"),
         solid_selection=data.get("solidSelection"),
     )
 
