@@ -1,9 +1,8 @@
-from datetime import datetime
-
 import graphene
+import pendulum
 from dagster.core.storage.pipeline_run import PipelineRunStatus, PipelineRunsFilter
 
-from .pipelines.status import GraphenePipelineRunStatus
+from .pipelines.status import GrapheneRunStatus
 from .runs import GrapheneRunConfigData
 from .util import non_null_list
 
@@ -23,18 +22,18 @@ class GrapheneExecutionTag(graphene.InputObjectType):
         name = "ExecutionTag"
 
 
-class GraphenePipelineRunsFilter(graphene.InputObjectType):
+class GrapheneRunsFilter(graphene.InputObjectType):
     runIds = graphene.List(graphene.String)
     pipelineName = graphene.Field(graphene.String)
     tags = graphene.List(graphene.NonNull(GrapheneExecutionTag))
-    statuses = graphene.List(graphene.NonNull(GraphenePipelineRunStatus))
+    statuses = graphene.List(graphene.NonNull(GrapheneRunStatus))
     snapshotId = graphene.Field(graphene.String)
     updatedAfter = graphene.Field(graphene.String)
+    mode = graphene.Field(graphene.String)
 
     class Meta:
-        description = """This type represents a filter on pipeline runs.
-        Currently, you may only pass one of the filter options."""
-        name = "PipelineRunsFilter"
+        description = """This type represents a filter on Dagster runs."""
+        name = "RunsFilter"
 
     def to_selector(self):
         if self.tags:
@@ -51,7 +50,7 @@ class GraphenePipelineRunsFilter(graphene.InputObjectType):
         else:
             statuses = None
 
-        updated_after = datetime.fromisoformat(self.updatedAfter) if self.updatedAfter else None
+        updated_after = pendulum.parse(self.updatedAfter) if self.updatedAfter else None
 
         return PipelineRunsFilter(
             run_ids=self.runIds,
@@ -60,6 +59,7 @@ class GraphenePipelineRunsFilter(graphene.InputObjectType):
             statuses=statuses,
             snapshot_id=self.snapshotId,
             updated_after=updated_after,
+            mode=self.mode,
         )
 
 
@@ -83,6 +83,18 @@ class GraphenePipelineSelector(graphene.InputObjectType):
         name = "PipelineSelector"
 
 
+class GrapheneJobOrPipelineSelector(graphene.InputObjectType):
+    pipelineName = graphene.String()
+    jobName = graphene.String()
+    repositoryName = graphene.NonNull(graphene.String)
+    repositoryLocationName = graphene.NonNull(graphene.String)
+    solidSelection = graphene.List(graphene.NonNull(graphene.String))
+
+    class Meta:
+        description = """This type represents the fields necessary to identify a job or pipeline"""
+        name = "JobOrPipelineSelector"
+
+
 class GrapheneRepositorySelector(graphene.InputObjectType):
     repositoryName = graphene.NonNull(graphene.String)
     repositoryLocationName = graphene.NonNull(graphene.String)
@@ -154,10 +166,10 @@ class GrapheneExecutionMetadata(graphene.InputObjectType):
 
 class GrapheneExecutionParams(graphene.InputObjectType):
     selector = graphene.NonNull(
-        GraphenePipelineSelector,
-        description="""Defines the pipeline and solid subset that should be executed.
+        GrapheneJobOrPipelineSelector,
+        description="""Defines the job / pipeline and solid subset that should be executed.
         All subsequent executions in the same run group (for example, a single-step
-        re-execution) are scoped to the original run's pipeline selector and solid
+        re-execution) are scoped to the original run's selector and solid
         subset.""",
     )
     runConfigData = graphene.Field(GrapheneRunConfigData)
@@ -206,16 +218,16 @@ class GrapheneStepExecution(graphene.InputObjectType):
         name = "StepExecution"
 
 
-class GrapheneJobSelector(graphene.InputObjectType):
+class GrapheneInstigationSelector(graphene.InputObjectType):
     class Meta:
-        name = "JobSelector"
+        name = "InstigationSelector"
         description = (
             """This type represents the fields necessary to identify a schedule or sensor."""
         )
 
     repositoryName = graphene.NonNull(graphene.String)
     repositoryLocationName = graphene.NonNull(graphene.String)
-    jobName = graphene.NonNull(graphene.String)
+    name = graphene.NonNull(graphene.String)
 
 
 types = [
@@ -223,12 +235,12 @@ types = [
     GrapheneExecutionMetadata,
     GrapheneExecutionParams,
     GrapheneExecutionTag,
-    GrapheneJobSelector,
+    GrapheneInstigationSelector,
     GrapheneMarshalledInput,
     GrapheneMarshalledOutput,
     GrapheneLaunchBackfillParams,
     GraphenePartitionSetSelector,
-    GraphenePipelineRunsFilter,
+    GrapheneRunsFilter,
     GraphenePipelineSelector,
     GrapheneRepositorySelector,
     GrapheneScheduleSelector,
