@@ -20,16 +20,12 @@ from ...implementation.fetch_sensors import get_sensors_for_pipeline
 from ...implementation.utils import UserFacingGraphQLError, capture_error
 from ..asset_key import GrapheneAssetKey
 from ..dagster_types import GrapheneDagsterType, GrapheneDagsterTypeOrError, to_dagster_type
-from ..errors import (
-    GrapheneDagsterTypeNotFoundError,
-    GraphenePipelineRunNotFoundError,
-    GraphenePythonError,
-)
+from ..errors import GrapheneDagsterTypeNotFoundError, GraphenePythonError, GrapheneRunNotFoundError
 from ..execution import GrapheneExecutionPlan
 from ..logs.compute_logs import GrapheneComputeLogs
 from ..logs.events import (
-    GraphenePipelineRunEvent,
-    GraphenePipelineRunStepStats,
+    GrapheneDagsterRunEvent,
+    GrapheneRunStepStats,
     GrapheneStepMaterializationEvent,
 )
 from ..paging import GrapheneCursor
@@ -47,13 +43,13 @@ from ..tags import GrapheneAssetTag, GraphenePipelineTag
 from ..util import non_null_list
 from .mode import GrapheneMode
 from .pipeline_ref import GraphenePipelineReference
-from .pipeline_run_stats import GraphenePipelineRunStatsOrError
-from .status import GraphenePipelineRunStatus
+from .pipeline_run_stats import GrapheneRunStatsSnapshotOrError
+from .status import GrapheneRunStatus
 
 
 class GrapheneAssetMaterialization(graphene.ObjectType):
     materializationEvent = graphene.NonNull(GrapheneStepMaterializationEvent)
-    runOrError = graphene.NonNull(lambda: GraphenePipelineRunOrError)
+    runOrError = graphene.NonNull(lambda: GrapheneRunOrError)
     partition = graphene.Field(graphene.String)
 
     class Meta:
@@ -90,12 +86,13 @@ class GrapheneAsset(graphene.ObjectType):
         limit=graphene.Int(),
     )
     tags = non_null_list(GrapheneAssetTag)
+    definition = graphene.Field("dagster_graphql.schema.asset_graph.GrapheneAssetNode")
 
     class Meta:
         name = "Asset"
 
-    def __init__(self, key, tags=None):
-        super().__init__(key=key)
+    def __init__(self, key, definition=None, tags=None):
+        super().__init__(key=key, definition=definition)
         check.opt_dict_param(tags, "tags", key_type=str, value_type=str)
         self._tags = tags
 
@@ -126,32 +123,26 @@ class GrapheneAsset(graphene.ObjectType):
         ]
 
     def resolve_tags(self, graphene_info):
-        from ...implementation.fetch_assets import get_asset_events
-
         if self._tags is not None:
             tags = self._tags
         else:
-            events = get_asset_events(graphene_info, self.key, limit=1)
-            tags = (
-                events[0].dagster_event.step_materialization_data.materialization.tags or {}
-                if events
-                else {}
-            )
+            tags = graphene_info.context.instance.get_asset_tags(self.key)
         return [GrapheneAssetTag(key=key, value=value) for key, value in tags.items()]
 
 
-class GraphenePipelineRun(graphene.ObjectType):
+class GraphenePipelineRun(graphene.Interface):
     id = graphene.NonNull(graphene.ID)
     runId = graphene.NonNull(graphene.String)
     # Nullable because of historical runs
     pipelineSnapshotId = graphene.String()
     repositoryOrigin = graphene.Field(GrapheneRepositoryOrigin)
-    status = graphene.NonNull(GraphenePipelineRunStatus)
+    status = graphene.NonNull(GrapheneRunStatus)
     pipeline = graphene.NonNull(GraphenePipelineReference)
     pipelineName = graphene.NonNull(graphene.String)
+    jobName = graphene.NonNull(graphene.String)
     solidSelection = graphene.List(graphene.NonNull(graphene.String))
-    stats = graphene.NonNull(GraphenePipelineRunStatsOrError)
-    stepStats = non_null_list(GraphenePipelineRunStepStats)
+    stats = graphene.NonNull(GrapheneRunStatsSnapshotOrError)
+    stepStats = non_null_list(GrapheneRunStepStats)
     computeLogs = graphene.Field(
         graphene.NonNull(GrapheneComputeLogs),
         stepKey=graphene.Argument(graphene.NonNull(graphene.String)),
@@ -169,13 +160,52 @@ class GraphenePipelineRun(graphene.ObjectType):
     canTerminate = graphene.NonNull(graphene.Boolean)
     assets = non_null_list(GrapheneAsset)
     events = graphene.Field(
-        non_null_list(GraphenePipelineRunEvent),
+        non_null_list(GrapheneDagsterRunEvent),
         after=graphene.Argument(GrapheneCursor),
     )
 
     class Meta:
         name = "PipelineRun"
 
+
+class GrapheneRun(graphene.ObjectType):
+    id = graphene.NonNull(graphene.ID)
+    runId = graphene.NonNull(graphene.String)
+    # Nullable because of historical runs
+    pipelineSnapshotId = graphene.String()
+    repositoryOrigin = graphene.Field(GrapheneRepositoryOrigin)
+    status = graphene.NonNull(GrapheneRunStatus)
+    pipeline = graphene.NonNull(GraphenePipelineReference)
+    pipelineName = graphene.NonNull(graphene.String)
+    jobName = graphene.NonNull(graphene.String)
+    solidSelection = graphene.List(graphene.NonNull(graphene.String))
+    stats = graphene.NonNull(GrapheneRunStatsSnapshotOrError)
+    stepStats = non_null_list(GrapheneRunStepStats)
+    computeLogs = graphene.Field(
+        graphene.NonNull(GrapheneComputeLogs),
+        stepKey=graphene.Argument(graphene.NonNull(graphene.String)),
+        description="""
+        Compute logs are the stdout/stderr logs for a given solid step computation
+        """,
+    )
+    executionPlan = graphene.Field(GrapheneExecutionPlan)
+    stepKeysToExecute = graphene.List(graphene.NonNull(graphene.String))
+    runConfigYaml = graphene.NonNull(graphene.String)
+    mode = graphene.NonNull(graphene.String)
+    tags = non_null_list(GraphenePipelineTag)
+    rootRunId = graphene.Field(graphene.String)
+    parentRunId = graphene.Field(graphene.String)
+    canTerminate = graphene.NonNull(graphene.Boolean)
+    assets = non_null_list(GrapheneAsset)
+    events = graphene.Field(
+        non_null_list(GrapheneDagsterRunEvent),
+        after=graphene.Argument(GrapheneCursor),
+    )
+
+    class Meta:
+        interfaces = (GraphenePipelineRun,)
+        name = "Run"
+
     def __init__(self, pipeline_run):
         super().__init__(
             runId=pipeline_run.run_id,
@@ -202,6 +232,9 @@ class GraphenePipelineRun(graphene.ObjectType):
     def resolve_pipelineName(self, _graphene_info):
         return self._pipeline_run.pipeline_name
 
+    def resolve_jobName(self, _graphene_info):
+        return self._pipeline_run.pipeline_name
+
     def resolve_solidSelection(self, _graphene_info):
         return self._pipeline_run.solid_selection
 
@@ -309,7 +342,7 @@ class GrapheneIPipelineSnapshotMixin:
     )
     tags = non_null_list(GraphenePipelineTag)
     runs = graphene.Field(
-        non_null_list(GraphenePipelineRun),
+        non_null_list(GrapheneRun),
         cursor=graphene.String(),
         limit=graphene.Int(),
     )
@@ -468,6 +501,15 @@ class GrapheneIPipelineSnapshot(graphene.Interface):
         handleID=graphene.Argument(graphene.NonNull(graphene.String)),
     )
     tags = non_null_list(GraphenePipelineTag)
+    runs = graphene.Field(
+        non_null_list(GrapheneRun),
+        cursor=graphene.String(),
+        limit=graphene.Int(),
+    )
+    schedules = non_null_list(GrapheneSchedule)
+    sensors = non_null_list(GrapheneSensor)
+    parent_snapshot_id = graphene.String()
+    graph_name = graphene.NonNull(graphene.String)
 
     class Meta:
         name = "IPipelineSnapshot"
@@ -516,11 +558,7 @@ class GraphenePipelinePreset(graphene.ObjectType):
 class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
     id = graphene.NonNull(graphene.ID)
     presets = non_null_list(GraphenePipelinePreset)
-    runs = graphene.Field(
-        non_null_list(GraphenePipelineRun),
-        cursor=graphene.String(),
-        limit=graphene.Int(),
-    )
+    isJob = graphene.NonNull(graphene.Boolean)
 
     class Meta:
         interfaces = (GrapheneSolidContainer, GrapheneIPipelineSnapshot)
@@ -544,6 +582,15 @@ class GraphenePipeline(GrapheneIPipelineSnapshotMixin, graphene.ObjectType):
             for preset in sorted(self._external_pipeline.active_presets, key=lambda item: item.name)
         ]
 
+    def resolve_isJob(self, _graphene_info):
+        return self._external_pipeline.is_job
+
+
+class GrapheneJob(GraphenePipeline):
+    class Meta:
+        interfaces = (GrapheneSolidContainer, GrapheneIPipelineSnapshot)
+        name = "Job"
+
 
 @lru_cache(maxsize=32)
 def _get_solid_handles(represented_pipeline):
@@ -556,7 +603,7 @@ def _get_solid_handles(represented_pipeline):
     }
 
 
-class GraphenePipelineRunOrError(graphene.Union):
+class GrapheneRunOrError(graphene.Union):
     class Meta:
-        types = (GraphenePipelineRun, GraphenePipelineRunNotFoundError, GraphenePythonError)
-        name = "PipelineRunOrError"
+        types = (GrapheneRun, GrapheneRunNotFoundError, GraphenePythonError)
+        name = "RunOrError"
