@@ -30,17 +30,17 @@ from ..backfill import (
 from ..errors import (
     GrapheneAssetNotFoundError,
     GrapheneConflictingExecutionParamsError,
-    GraphenePipelineRunNotFoundError,
     GraphenePresetNotFoundError,
     GraphenePythonError,
     GrapheneReloadNotSupported,
     GrapheneRepositoryLocationNotFound,
+    GrapheneRunNotFoundError,
     GrapheneUnauthorizedError,
 )
 from ..external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
 from ..inputs import GrapheneAssetKeyInput, GrapheneExecutionParams, GrapheneLaunchBackfillParams
-from ..pipelines.pipeline import GraphenePipelineRun
-from ..runs import GrapheneLaunchPipelineExecutionResult, GrapheneLaunchPipelineReexecutionResult
+from ..pipelines.pipeline import GrapheneRun
+from ..runs import GrapheneLaunchRunReexecutionResult, GrapheneLaunchRunResult
 from ..schedules import (
     GrapheneReconcileSchedulerStateMutation,
     GrapheneStartScheduleMutation,
@@ -131,7 +131,7 @@ class GrapheneDeletePipelineRunResult(graphene.Union):
             GrapheneDeletePipelineRunSuccess,
             GrapheneUnauthorizedError,
             GraphenePythonError,
-            GraphenePipelineRunNotFoundError,
+            GrapheneRunNotFoundError,
         )
         name = "DeletePipelineRunResult"
 
@@ -152,31 +152,48 @@ class GrapheneDeleteRunMutation(graphene.Mutation):
         return delete_pipeline_run(graphene_info, run_id)
 
 
-class GrapheneTerminatePipelineExecutionSuccess(graphene.ObjectType):
-    run = graphene.Field(graphene.NonNull(GraphenePipelineRun))
+class GrapheneTerminatePipelineExecutionSuccess(graphene.Interface):
+    run = graphene.Field(graphene.NonNull(GrapheneRun))
 
     class Meta:
         name = "TerminatePipelineExecutionSuccess"
 
 
-class GrapheneTerminatePipelineExecutionFailure(graphene.ObjectType):
-    run = graphene.NonNull(GraphenePipelineRun)
+class GrapheneTerminateRunSuccess(graphene.ObjectType):
+    run = graphene.Field(graphene.NonNull(GrapheneRun))
+
+    class Meta:
+        interfaces = (GrapheneTerminatePipelineExecutionSuccess,)
+        name = "TerminateRunSuccess"
+
+
+class GrapheneTerminatePipelineExecutionFailure(graphene.Interface):
+    run = graphene.NonNull(GrapheneRun)
     message = graphene.NonNull(graphene.String)
 
     class Meta:
         name = "TerminatePipelineExecutionFailure"
 
 
-class GrapheneTerminatePipelineExecutionResult(graphene.Union):
+class GrapheneTerminateRunFailure(graphene.ObjectType):
+    run = graphene.NonNull(GrapheneRun)
+    message = graphene.NonNull(graphene.String)
+
+    class Meta:
+        interfaces = (GrapheneTerminatePipelineExecutionFailure,)
+        name = "TerminateRunFailure"
+
+
+class GrapheneTerminateRunResult(graphene.Union):
     class Meta:
         types = (
-            GrapheneTerminatePipelineExecutionSuccess,
-            GrapheneTerminatePipelineExecutionFailure,
-            GraphenePipelineRunNotFoundError,
+            GrapheneTerminateRunSuccess,
+            GrapheneTerminateRunFailure,
+            GrapheneRunNotFoundError,
             GrapheneUnauthorizedError,
             GraphenePythonError,
         )
-        name = "TerminatePipelineExecutionResult"
+        name = "TerminateRunResult"
 
 
 @capture_error
@@ -189,16 +206,16 @@ def create_execution_params_and_launch_pipeline_exec(graphene_info, execution_pa
     )
 
 
-class GrapheneLaunchPipelineExecutionMutation(graphene.Mutation):
+class GrapheneLaunchRunMutation(graphene.Mutation):
 
-    Output = graphene.NonNull(GrapheneLaunchPipelineExecutionResult)
+    Output = graphene.NonNull(GrapheneLaunchRunResult)
 
     class Arguments:
         executionParams = graphene.NonNull(GrapheneExecutionParams)
 
     class Meta:
-        description = "Launch a pipeline run via the run launcher configured on the instance."
-        name = "LaunchPipelineExecutionMutation"
+        description = "Launch a run via the run launcher configured on the instance."
+        name = "LaunchRunMutation"
 
     @capture_error
     @check_permission(Permissions.LAUNCH_PIPELINE_EXECUTION)
@@ -266,15 +283,15 @@ def create_execution_params_and_launch_pipeline_reexec(graphene_info, execution_
     )
 
 
-class GrapheneLaunchPipelineReexecutionMutation(graphene.Mutation):
-    Output = graphene.NonNull(GrapheneLaunchPipelineReexecutionResult)
+class GrapheneLaunchRunReexecutionMutation(graphene.Mutation):
+    Output = graphene.NonNull(GrapheneLaunchRunReexecutionResult)
 
     class Arguments:
         executionParams = graphene.NonNull(GrapheneExecutionParams)
 
     class Meta:
-        description = "Re-launch a pipeline run via the run launcher configured on the instance"
-        name = "LaunchPipelineReexecutionMutation"
+        description = "Re-launch a run via the run launcher configured on the instance"
+        name = "LaunchRunReexecutionMutation"
 
     @capture_error
     @check_permission(Permissions.LAUNCH_PIPELINE_REEXECUTION)
@@ -285,7 +302,7 @@ class GrapheneLaunchPipelineReexecutionMutation(graphene.Mutation):
         )
 
 
-class GrapheneTerminatePipelinePolicy(graphene.Enum):
+class GrapheneTerminateRunPolicy(graphene.Enum):
     # Default behavior: Only mark as canceled if the termination is successful, and after all
     # resources peforming the execution have been shut down.
     SAFE_TERMINATE = "SAFE_TERMINATE"
@@ -295,18 +312,18 @@ class GrapheneTerminatePipelinePolicy(graphene.Enum):
     MARK_AS_CANCELED_IMMEDIATELY = "MARK_AS_CANCELED_IMMEDIATELY"
 
     class Meta:
-        name = "TerminatePipelinePolicy"
+        name = "TerminateRunPolicy"
 
 
-class GrapheneTerminatePipelineExecutionMutation(graphene.Mutation):
-    Output = graphene.NonNull(GrapheneTerminatePipelineExecutionResult)
+class GrapheneTerminateRunMutation(graphene.Mutation):
+    Output = graphene.NonNull(GrapheneTerminateRunResult)
 
     class Arguments:
         runId = graphene.NonNull(graphene.String)
-        terminatePolicy = graphene.Argument(GrapheneTerminatePipelinePolicy)
+        terminatePolicy = graphene.Argument(GrapheneTerminateRunPolicy)
 
     class Meta:
-        name = "TerminatePipelineExecutionMutation"
+        name = "TerminateRunMutation"
 
     @capture_error
     @check_permission(Permissions.TERMINATE_PIPELINE_EXECUTION)
@@ -314,7 +331,7 @@ class GrapheneTerminatePipelineExecutionMutation(graphene.Mutation):
         return terminate_pipeline_execution(
             graphene_info,
             kwargs["runId"],
-            kwargs.get("terminatePolicy", GrapheneTerminatePipelinePolicy.SAFE_TERMINATE),
+            kwargs.get("terminatePolicy", GrapheneTerminateRunPolicy.SAFE_TERMINATE),
         )
 
 
@@ -461,15 +478,19 @@ class GrapheneAssetWipeMutation(graphene.Mutation):
 
 
 class GrapheneMutation(graphene.ObjectType):
-    launch_pipeline_execution = GrapheneLaunchPipelineExecutionMutation.Field()
-    launch_pipeline_reexecution = GrapheneLaunchPipelineReexecutionMutation.Field()
+    launch_pipeline_execution = GrapheneLaunchRunMutation.Field()
+    launch_run = GrapheneLaunchRunMutation.Field()
+    launch_pipeline_reexecution = GrapheneLaunchRunReexecutionMutation.Field()
+    launch_run_reexecution = GrapheneLaunchRunReexecutionMutation.Field()
     reconcile_scheduler_state = GrapheneReconcileSchedulerStateMutation.Field()
     start_schedule = GrapheneStartScheduleMutation.Field()
     stop_running_schedule = GrapheneStopRunningScheduleMutation.Field()
     start_sensor = GrapheneStartSensorMutation.Field()
     stop_sensor = GrapheneStopSensorMutation.Field()
-    terminate_pipeline_execution = GrapheneTerminatePipelineExecutionMutation.Field()
+    terminate_pipeline_execution = GrapheneTerminateRunMutation.Field()
+    terminate_run = GrapheneTerminateRunMutation.Field()
     delete_pipeline_run = GrapheneDeleteRunMutation.Field()
+    delete_run = GrapheneDeleteRunMutation.Field()
     reload_repository_location = GrapheneReloadRepositoryLocationMutation.Field()
     reload_workspace = GrapheneReloadWorkspaceMutation.Field()
     shutdown_repository_location = GrapheneShutdownRepositoryLocationMutation.Field()
