@@ -45,9 +45,9 @@ from ..external import (
 from ..inputs import (
     GrapheneAssetKeyInput,
     GrapheneInstigationSelector,
-    GraphenePipelineRunsFilter,
     GraphenePipelineSelector,
     GrapheneRepositorySelector,
+    GrapheneRunsFilter,
     GrapheneScheduleSelector,
     GrapheneSensorSelector,
 )
@@ -60,15 +60,15 @@ from ..instigation import (
 from ..partition_sets import GraphenePartitionSetOrError, GraphenePartitionSetsOrError
 from ..permissions import GraphenePermission
 from ..pipelines.config_result import GraphenePipelineConfigValidationResult
-from ..pipelines.pipeline import GraphenePipelineRunOrError
+from ..pipelines.pipeline import GrapheneRunOrError
 from ..pipelines.snapshot import GraphenePipelineSnapshotOrError
 from ..run_config import GrapheneRunConfigSchemaOrError
 from ..runs import (
-    GraphenePipelineRuns,
-    GraphenePipelineRunsOrError,
     GrapheneRunConfigData,
     GrapheneRunGroupOrError,
     GrapheneRunGroupsOrError,
+    GrapheneRuns,
+    GrapheneRunsOrError,
 )
 from ..schedules import GrapheneScheduleOrError, GrapheneSchedulerOrError, GrapheneSchedulesOrError
 from ..sensors import GrapheneSensorOrError, GrapheneSensorsOrError
@@ -143,16 +143,23 @@ class GrapheneQuery(graphene.ObjectType):
     )
 
     pipelineRunsOrError = graphene.Field(
-        graphene.NonNull(GraphenePipelineRunsOrError),
-        filter=graphene.Argument(GraphenePipelineRunsFilter),
+        graphene.NonNull(GrapheneRunsOrError),
+        filter=graphene.Argument(GrapheneRunsFilter),
         cursor=graphene.String(),
         limit=graphene.Int(),
     )
-
     pipelineRunOrError = graphene.Field(
-        graphene.NonNull(GraphenePipelineRunOrError), runId=graphene.NonNull(graphene.ID)
+        graphene.NonNull(GrapheneRunOrError), runId=graphene.NonNull(graphene.ID)
+    )
+    runsOrError = graphene.Field(
+        graphene.NonNull(GrapheneRunsOrError),
+        filter=graphene.Argument(GrapheneRunsFilter),
+        cursor=graphene.String(),
+        limit=graphene.Int(),
+    )
+    runOrError = graphene.Field(
+        graphene.NonNull(GrapheneRunOrError), runId=graphene.NonNull(graphene.ID)
     )
-
     pipelineRunTags = non_null_list(GraphenePipelineTagAndValues)
 
     runGroupOrError = graphene.Field(
@@ -161,7 +168,7 @@ class GrapheneQuery(graphene.ObjectType):
 
     runGroupsOrError = graphene.Field(
         graphene.NonNull(GrapheneRunGroupsOrError),
-        filter=graphene.Argument(GraphenePipelineRunsFilter),
+        filter=graphene.Argument(GrapheneRunsFilter),
         cursor=graphene.String(),
         limit=graphene.Int(),
     )
@@ -196,7 +203,12 @@ class GrapheneQuery(graphene.ObjectType):
 
     instance = graphene.NonNull(GrapheneInstance)
 
-    assetsOrError = graphene.NonNull(GrapheneAssetsOrError)
+    assetsOrError = graphene.Field(
+        graphene.NonNull(GrapheneAssetsOrError),
+        prefix=graphene.List(graphene.NonNull(graphene.String)),
+        cursor=graphene.String(),
+        limit=graphene.Int(),
+    )
 
     assetOrError = graphene.Field(
         graphene.NonNull(GrapheneAssetOrError),
@@ -304,7 +316,7 @@ class GrapheneQuery(graphene.ObjectType):
         if filters is not None:
             filters = filters.to_selector()
 
-        return GraphenePipelineRuns(
+        return GrapheneRuns(
             filters=filters,
             cursor=kwargs.get("cursor"),
             limit=kwargs.get("limit"),
@@ -313,6 +325,20 @@ class GrapheneQuery(graphene.ObjectType):
     def resolve_pipelineRunOrError(self, graphene_info, runId):
         return get_run_by_id(graphene_info, runId)
 
+    def resolve_runsOrError(self, _graphene_info, **kwargs):
+        filters = kwargs.get("filter")
+        if filters is not None:
+            filters = filters.to_selector()
+
+        return GrapheneRuns(
+            filters=filters,
+            cursor=kwargs.get("cursor"),
+            limit=kwargs.get("limit"),
+        )
+
+    def resolve_runOrError(self, graphene_info, runId):
+        return get_run_by_id(graphene_info, runId)
+
     def resolve_runGroupsOrError(self, graphene_info, **kwargs):
         filters = kwargs.get("filter")
         if filters is not None:
@@ -376,8 +402,13 @@ class GrapheneQuery(graphene.ObjectType):
     def resolve_assetNodeOrError(self, graphene_info, **kwargs):
         return get_asset_node(graphene_info, AssetKey.from_graphql_input(kwargs["assetKey"]))
 
-    def resolve_assetsOrError(self, graphene_info):
-        return get_assets(graphene_info)
+    def resolve_assetsOrError(self, graphene_info, **kwargs):
+        return get_assets(
+            graphene_info,
+            prefix=kwargs.get("prefix"),
+            cursor=kwargs.get("cursor"),
+            limit=kwargs.get("limit"),
+        )
 
     def resolve_assetOrError(self, graphene_info, **kwargs):
         return get_asset(graphene_info, AssetKey.from_graphql_input(kwargs["assetKey"]))
