@@ -1,5 +1,4 @@
 import graphene
-import pendulum
 from dagster import check
 from dagster.core.host_representation import ExternalSchedule
 from dagster.seven import get_current_datetime_in_utc, get_timestamp_from_utc_datetime
@@ -9,7 +8,11 @@ from ..errors import (
     GrapheneRepositoryNotFoundError,
     GrapheneScheduleNotFoundError,
 )
-from ..jobs import GrapheneFutureJobTick, GrapheneFutureJobTicks, GrapheneJobState
+from ..instigation import (
+    GrapheneFutureInstigationTick,
+    GrapheneFutureInstigationTicks,
+    GrapheneInstigationState,
+)
 from ..util import non_null_list
 
 
@@ -22,13 +25,13 @@ class GrapheneSchedule(graphene.ObjectType):
     mode = graphene.NonNull(graphene.String)
     execution_timezone = graphene.Field(graphene.String)
     description = graphene.String()
-    scheduleState = graphene.NonNull(GrapheneJobState)
+    scheduleState = graphene.NonNull(GrapheneInstigationState)
     partition_set = graphene.Field("dagster_graphql.schema.partition_sets.GraphenePartitionSet")
     futureTicks = graphene.NonNull(
-        GrapheneFutureJobTicks, cursor=graphene.Float(), limit=graphene.Int()
+        GrapheneFutureInstigationTicks, cursor=graphene.Float(), limit=graphene.Int()
     )
     futureTick = graphene.NonNull(
-        GrapheneFutureJobTick, tick_timestamp=graphene.NonNull(graphene.Int)
+        GrapheneFutureInstigationTick, tick_timestamp=graphene.NonNull(graphene.Int)
     )
 
     class Meta:
@@ -45,7 +48,7 @@ class GrapheneSchedule(graphene.ObjectType):
         if not self._schedule_state:
             # Also include a ScheduleState for a stopped schedule that may not
             # have a stored database row yet
-            self._schedule_state = self._external_schedule.get_default_job_state(
+            self._schedule_state = self._external_schedule.get_default_instigation_state(
                 graphene_info.context.instance
             )
 
@@ -55,17 +58,17 @@ class GrapheneSchedule(graphene.ObjectType):
             pipeline_name=external_schedule.pipeline_name,
             solid_selection=external_schedule.solid_selection,
             mode=external_schedule.mode,
-            scheduleState=GrapheneJobState(self._schedule_state),
+            scheduleState=GrapheneInstigationState(self._schedule_state),
             execution_timezone=(
                 self._external_schedule.execution_timezone
                 if self._external_schedule.execution_timezone
-                else pendulum.now().timezone.name
+                else "UTC"
             ),
             description=external_schedule.description,
         )
 
     def resolve_id(self, _):
-        return "%s:%s" % (self.name, self.pipeline_name)
+        return self._external_schedule.get_external_origin_id()
 
     def resolve_partition_set(self, graphene_info):
         from ..partition_sets import GraphenePartitionSet
@@ -98,13 +101,14 @@ class GrapheneSchedule(graphene.ObjectType):
             tick_times.append(next(time_iter).timestamp())
 
         future_ticks = [
-            GrapheneFutureJobTick(self._schedule_state, tick_time) for tick_time in tick_times
+            GrapheneFutureInstigationTick(self._schedule_state, tick_time)
+            for tick_time in tick_times
         ]
 
-        return GrapheneFutureJobTicks(results=future_ticks, cursor=tick_times[-1] + 1)
+        return GrapheneFutureInstigationTicks(results=future_ticks, cursor=tick_times[-1] + 1)
 
     def resolve_futureTick(self, _graphene_info, tick_timestamp):
-        return GrapheneFutureJobTick(self._schedule_state, float(tick_timestamp))
+        return GrapheneFutureInstigationTick(self._schedule_state, float(tick_timestamp))
 
 
 class GrapheneScheduleOrError(graphene.Union):
