@@ -62,7 +62,7 @@ from dagster.core.log_manager import coerce_valid_log_level
 from dagster.core.storage.fs_io_manager import fs_io_manager
 from dagster.core.storage.pipeline_run import PipelineRunStatus, PipelineRunsFilter
 from dagster.core.storage.tags import RESUME_RETRY_TAG
-from dagster.core.test_utils import today_at_midnight
+from dagster.core.test_utils import default_mode_def_for_test, today_at_midnight
 from dagster.core.workspace.context import WorkspaceProcessContext
 from dagster.core.workspace.load_target import PythonFileTarget
 from dagster.seven import get_system_temp_directory
@@ -74,7 +74,7 @@ from dagster_graphql.test.utils import (
     main_repo_name,
 )
 
-LONG_INT = 29119888133298982934829348
+LONG_INT = 2875972244  # 32b unsigned, > 32b signed
 
 
 @dagster_type_loader(String)
@@ -173,15 +173,6 @@ def csv_hello_world_solids_config():
     }
 
 
-def csv_hello_world_solids_config_fs_storage():
-    return {
-        "solids": {
-            "sum_solid": {"inputs": {"num": file_relative_path(__file__, "../data/num.csv")}}
-        },
-        "intermediate_storage": {"filesystem": {}},
-    }
-
-
 @solid(config_schema={"file": Field(String)})
 def loop(context):
     with open(context.solid_config["file"], "w") as ff:
@@ -345,6 +336,7 @@ def more_complicated_nested_config():
 
 
 @pipeline(
+    mode_defs=[default_mode_def_for_test],
     preset_defs=[
         PresetDefinition.from_files(
             name="prod",
@@ -368,20 +360,20 @@ def more_complicated_nested_config():
                 }
             },
         ),
-    ]
+    ],
 )
 def csv_hello_world():
     sum_sq_solid(sum_df=sum_solid())
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def csv_hello_world_with_expectations():
     ss = sum_solid()
     sum_sq_solid(sum_df=ss)
     df_expectations_solid(sum_df=ss)
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def csv_hello_world_two():
     sum_solid()
 
@@ -391,7 +383,7 @@ def solid_that_gets_tags(context):
     return context.pipeline_run.tags
 
 
-@pipeline(tags={"tag_key": "tag_value"})
+@pipeline(mode_defs=[default_mode_def_for_test], tags={"tag_key": "tag_value"})
 def hello_world_with_tags():
     solid_that_gets_tags()
 
@@ -406,12 +398,12 @@ def pipeline_with_list():
     solid_def()
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def csv_hello_world_df_input():
     sum_sq_solid(sum_solid())
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def no_config_pipeline():
     @lambda_solid
     def return_hello():
@@ -590,13 +582,20 @@ def bar_logger(init_context):
 @pipeline(
     mode_defs=[
         ModeDefinition(
-            name="foo_mode", logger_defs={"foo": foo_logger}, description="Mode with foo logger"
+            name="foo_mode",
+            resource_defs={"io_manager": fs_io_manager},
+            logger_defs={"foo": foo_logger},
+            description="Mode with foo logger",
         ),
         ModeDefinition(
-            name="bar_mode", logger_defs={"bar": bar_logger}, description="Mode with bar logger"
+            name="bar_mode",
+            resource_defs={"io_manager": fs_io_manager},
+            logger_defs={"bar": bar_logger},
+            description="Mode with bar logger",
         ),
         ModeDefinition(
             name="foobar_mode",
+            resource_defs={"io_manager": fs_io_manager},
             logger_defs={"foo": foo_logger, "bar": bar_logger},
             description="Mode with multiple loggers",
         ),
@@ -763,7 +762,13 @@ def will_fail(context, num):  # pylint: disable=unused-argument
     raise Exception("fail")
 
 
-@pipeline(mode_defs=[ModeDefinition(resource_defs={"a": resource_a, "b": resource_b})])
+@pipeline(
+    mode_defs=[
+        ModeDefinition(
+            resource_defs={"a": resource_a, "b": resource_b, "io_manager": fs_io_manager}
+        )
+    ]
+)
 def retry_resource_pipeline():
     will_fail(start())
 
@@ -803,7 +808,7 @@ def no_output(_):
     yield ExpectationResult(True)
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def retry_multi_output_pipeline():
     multi_success, multi_skip = multi()
     fail, skip = can_fail(multi_success)
@@ -812,7 +817,7 @@ def retry_multi_output_pipeline():
     no_output.alias("grandchild_fail")(passthrough.alias("child_fail")(fail))
 
 
-@pipeline(tags={"foo": "bar"})
+@pipeline(tags={"foo": "bar"}, mode_defs=[default_mode_def_for_test])
 def tagged_pipeline():
     @lambda_solid
     def simple_solid():
@@ -821,7 +826,7 @@ def tagged_pipeline():
     simple_solid()
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def retry_multi_input_early_terminate_pipeline():
     @lambda_solid(output_def=OutputDefinition(Int))
     def return_one():
@@ -860,7 +865,7 @@ def retry_multi_input_early_terminate_pipeline():
     sum_inputs(input_one=get_input_one(step_one), input_two=get_input_two(step_one))
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def dynamic_pipeline():
     @solid
     def multiply_by_two(context, y):
@@ -907,13 +912,12 @@ def get_retry_multi_execution_params(graphql_context, should_fail, retry_id=None
         "mode": "default",
         "selector": selector,
         "runConfigData": {
-            "intermediate_storage": {"filesystem": {}},
             "solids": {"can_fail": {"config": {"fail": should_fail}}},
         },
         "executionMetadata": {
             "rootRunId": retry_id,
             "parentRunId": retry_id,
-            "tags": [{"key": RESUME_RETRY_TAG, "value": "true"}],
+            "tags": ([{"key": RESUME_RETRY_TAG, "value": "true"}] if retry_id else []),
         },
     }
 
@@ -942,7 +946,6 @@ def define_schedules():
         name="scheduled_integer_partitions",
         pipeline_name="no_config_pipeline",
         partition_fn=lambda: [Partition(x) for x in range(1, 10)],
-        run_config_fn_for_partition=lambda _partition: {"intermediate_storage": {"filesystem": {}}},
         tags_fn_for_partition=lambda _partition: {"test": "1234"},
     )
 
@@ -950,21 +953,18 @@ def define_schedules():
         name="no_config_pipeline_hourly_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"intermediate_storage": {"filesystem": {}}},
     )
 
     no_config_pipeline_hourly_schedule_with_config_fn = ScheduleDefinition(
         name="no_config_pipeline_hourly_schedule_with_config_fn",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config_fn=lambda _context: {"intermediate_storage": {"filesystem": {}}},
     )
 
     no_config_should_execute = ScheduleDefinition(
         name="no_config_should_execute",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config={"intermediate_storage": {"filesystem": {}}},
         should_execute=lambda _context: False,
     )
 
@@ -972,7 +972,6 @@ def define_schedules():
         name="dynamic_config",
         cron_schedule="0 0 * * *",
         pipeline_name="no_config_pipeline",
-        run_config_fn=lambda _context: {"intermediate_storage": {"filesystem": {}}},
     )
 
     partition_based = integer_partition_set.create_schedule_definition(
@@ -987,7 +986,7 @@ def define_schedules():
         execution_time=(datetime.datetime.now() + datetime.timedelta(hours=2)).time(),
     )
     def partition_based_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @daily_schedule(
         pipeline_name="multi_mode_with_loggers",
@@ -996,7 +995,7 @@ def define_schedules():
         mode="foo_mode",
     )
     def partition_based_multi_mode_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @hourly_schedule(
         pipeline_name="no_config_chain_pipeline",
@@ -1005,7 +1004,7 @@ def define_schedules():
         solid_selection=["return_foo"],
     )
     def solid_selection_hourly_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @daily_schedule(
         pipeline_name="no_config_chain_pipeline",
@@ -1014,7 +1013,7 @@ def define_schedules():
         solid_selection=["return_foo"],
     )
     def solid_selection_daily_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @monthly_schedule(
         pipeline_name="no_config_chain_pipeline",
@@ -1023,7 +1022,7 @@ def define_schedules():
         solid_selection=["return_foo"],
     )
     def solid_selection_monthly_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @weekly_schedule(
         pipeline_name="no_config_chain_pipeline",
@@ -1032,7 +1031,7 @@ def define_schedules():
         solid_selection=["return_foo"],
     )
     def solid_selection_weekly_decorator(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     # Schedules for testing the user error boundary
     @daily_schedule(
@@ -1041,7 +1040,7 @@ def define_schedules():
         should_execute=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def should_execute_error_schedule(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
@@ -1049,7 +1048,7 @@ def define_schedules():
         tags_fn_for_date=lambda _: asdf,  # pylint: disable=undefined-variable
     )
     def tags_error_schedule(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     @daily_schedule(
         pipeline_name="no_config_pipeline",
@@ -1064,20 +1063,18 @@ def define_schedules():
         execution_timezone="US/Central",
     )
     def timezone_schedule(_date):
-        return {"intermediate_storage": {"filesystem": {}}}
+        return {}
 
     tagged_pipeline_schedule = ScheduleDefinition(
         name="tagged_pipeline_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="tagged_pipeline",
-        run_config={"intermediate_storage": {"filesystem": {}}},
     )
 
     tagged_pipeline_override_schedule = ScheduleDefinition(
         name="tagged_pipeline_override_schedule",
         cron_schedule="0 0 * * *",
         pipeline_name="tagged_pipeline",
-        run_config={"intermediate_storage": {"filesystem": {}}},
         tags={"foo": "notbar"},
     )
 
@@ -1117,7 +1114,6 @@ def define_partitions():
         solid_selection=["return_hello"],
         mode="default",
         partition_fn=lambda: [Partition(i) for i in range(10)],
-        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
         tags_fn_for_partition=lambda partition: {"foo": partition.name},
     )
 
@@ -1125,7 +1121,6 @@ def define_partitions():
         name="enum_partition",
         pipeline_name="noop_pipeline",
         partition_fn=lambda: ["one", "two", "three"],
-        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
     )
 
     chained_partition_set = PartitionSetDefinition(
@@ -1133,14 +1128,12 @@ def define_partitions():
         pipeline_name="chained_failure_pipeline",
         mode="default",
         partition_fn=lambda: [Partition(i) for i in range(10)],
-        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
     )
 
     alphabet_partition_set = PartitionSetDefinition(
         name="alpha_partition",
         pipeline_name="no_config_pipeline",
         partition_fn=lambda: list(string.ascii_lowercase),
-        run_config_fn_for_partition=lambda _: {"intermediate_storage": {"filesystem": {}}},
     )
 
     return [integer_set, enum_set, chained_partition_set, alphabet_partition_set]
@@ -1151,7 +1144,6 @@ def define_sensors():
     def always_no_config_sensor(_):
         return RunRequest(
             run_key=None,
-            run_config={"intermediate_storage": {"filesystem": {}}},
             tags={"test": "1234"},
         )
 
@@ -1159,7 +1151,6 @@ def define_sensors():
     def once_no_config_sensor(_):
         return RunRequest(
             run_key="once",
-            run_config={"intermediate_storage": {"filesystem": {}}},
             tags={"test": "1234"},
         )
 
@@ -1176,7 +1167,6 @@ def define_sensors():
     def custom_interval_sensor(_):
         return RunRequest(
             run_key=None,
-            run_config={"intermediate_storage": {"filesystem": {}}},
             tags={"test": "1234"},
         )
 
@@ -1189,7 +1179,7 @@ def define_sensors():
     ]
 
 
-@pipeline
+@pipeline(mode_defs=[default_mode_def_for_test])
 def chained_failure_pipeline():
     @lambda_solid
     def always_succeed():
@@ -1243,6 +1233,11 @@ def simple_graph():
     noop_solid()
 
 
+@graph
+def composed_graph():
+    simple_graph()
+
+
 @repository
 def empty_repo():
     return []
@@ -1290,6 +1285,7 @@ def define_pipelines():
         backcompat_materialization_pipeline,
         simple_graph.to_job("simple_job_a"),
         simple_graph.to_job("simple_job_b"),
+        composed_graph.to_job(),
     ]
 
 
