@@ -1,11 +1,14 @@
+import time
+
+from dagster import AssetKey
 from dagster_graphql.client.query import LAUNCH_PIPELINE_EXECUTION_MUTATION
 from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
 
 from .graphql_context_test_suite import GraphQLContextVariant, make_graphql_context_test_suite
 
 GET_ASSET_KEY_QUERY = """
-    query AssetKeyQuery($prefixPath: [String!]) {
-        assetsOrError(prefixPath: $prefixPath) {
+    query AssetKeyQuery {
+        assetsOrError {
             __typename
             ...on AssetConnection {
                 nodes {
@@ -27,8 +30,18 @@ GET_ASSET_MATERIALIZATION = """
                         materialization {
                             label
                         }
+                        assetLineage {
+                            assetKey {
+                                path
+                            }
+                            partitions
+                        }
                     }
                 }
+                tags {
+                    key
+                    value
+                }
             }
             ... on AssetNotFoundError {
                 __typename
@@ -54,12 +67,23 @@ GET_ASSET_MATERIALIZATION_WITH_PARTITION = """
     }
 """
 
-GET_ASSET_RUNS = """
-    query AssetRunsQuery($assetKey: AssetKeyInput!) {
+
+WIPE_ASSETS = """
+    mutation AssetKeyWipe($assetKeys: [AssetKeyInput!]!) {
+        wipeAssets(assetKeys: $assetKeys) {
+            __typename
+        }
+    }
+"""
+
+GET_ASSET_MATERIALIZATION_TIMESTAMP = """
+    query AssetQuery($assetKey: AssetKeyInput!, $asOf: String) {
         assetOrError(assetKey: $assetKey) {
             ... on Asset {
-                runs {
-                    runId
+                assetMaterializations(beforeTimestampMillis: $asOf) {
+                    materializationEvent {
+                        timestamp
+                    }
                 }
             }
         }
@@ -67,6 +91,18 @@ GET_ASSET_RUNS = """
 """
 
 
+def _create_run(graphql_context, pipeline_name, mode="default"):
+    selector = infer_pipeline_selector(graphql_context, pipeline_name)
+    result = execute_dagster_graphql(
+        graphql_context,
+        LAUNCH_PIPELINE_EXECUTION_MUTATION,
+        variables={"executionParams": {"selector": selector, "mode": mode}},
+    )
+    assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
+    graphql_context.instance.run_launcher.join()
+    return result.data["launchPipelineExecution"]["run"]["runId"]
+
+
 class TestAssetAwareEventLog(
     make_graphql_context_test_suite(
         context_variants=[
@@ -76,43 +112,9 @@ class TestAssetAwareEventLog(
         ]
     )
 ):
-    def test_get_all_asset_keys(self, graphql_context, snapshot):
-        selector = infer_pipeline_selector(graphql_context, "multi_asset_pipeline")
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-
-        graphql_context.instance.run_launcher.join()
-
-        result = execute_dagster_graphql(
-            graphql_context, GET_ASSET_KEY_QUERY, variables={"prefixPath": None}
-        )
-        assert result.data
-        assert result.data["assetsOrError"]
-        assert result.data["assetsOrError"]["nodes"]
-
-        # sort by materialization asset key to keep list order is consistent for snapshot
-        result.data["assetsOrError"]["nodes"].sort(key=lambda e: e["key"]["path"][0])
-
-        snapshot.assert_match(result.data)
-
-    def test_get_prefixed_asset_keys(self, graphql_context, snapshot):
-        selector = infer_pipeline_selector(graphql_context, "multi_asset_pipeline")
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-
-        graphql_context.instance.run_launcher.join()
-
-        result = execute_dagster_graphql(
-            graphql_context, GET_ASSET_KEY_QUERY, variables={"prefixPath": ["a"]}
-        )
+    def test_all_asset_keys(self, graphql_context, snapshot):
+        _create_run(graphql_context, "multi_asset_pipeline")
+        result = execute_dagster_graphql(graphql_context, GET_ASSET_KEY_QUERY)
         assert result.data
         assert result.data["assetsOrError"]
         assert result.data["assetsOrError"]["nodes"]
@@ -123,13 +125,7 @@ class TestAssetAwareEventLog(
         snapshot.assert_match(result.data)
 
     def test_get_asset_key_materialization(self, graphql_context, snapshot):
-        selector = infer_pipeline_selector(graphql_context, "single_asset_pipeline")
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        _create_run(graphql_context, "single_asset_pipeline")
         result = execute_dagster_graphql(
             graphql_context, GET_ASSET_MATERIALIZATION, variables={"assetKey": {"path": ["a"]}}
         )
@@ -137,15 +133,7 @@ class TestAssetAwareEventLog(
         snapshot.assert_match(result.data)
 
     def test_get_asset_key_not_found(self, graphql_context, snapshot):
-        selector = infer_pipeline_selector(graphql_context, "single_asset_pipeline")
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-
-        graphql_context.instance.run_launcher.join()
+        _create_run(graphql_context, "single_asset_pipeline")
 
         result = execute_dagster_graphql(
             graphql_context,
@@ -156,15 +144,7 @@ class TestAssetAwareEventLog(
         snapshot.assert_match(result.data)
 
     def test_get_partitioned_asset_key_materialization(self, graphql_context, snapshot):
-        selector = infer_pipeline_selector(graphql_context, "partitioned_asset_pipeline")
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-
-        graphql_context.instance.run_launcher.join()
+        _create_run(graphql_context, "partitioned_asset_pipeline")
 
         result = execute_dagster_graphql(
             graphql_context,
@@ -174,33 +154,109 @@ class TestAssetAwareEventLog(
         assert result.data
         snapshot.assert_match(result.data)
 
-    def test_get_asset_runs(self, graphql_context):
-        single_selector = infer_pipeline_selector(graphql_context, "single_asset_pipeline")
-        multi_selector = infer_pipeline_selector(graphql_context, "multi_asset_pipeline")
+    def test_get_asset_key_lineage(self, graphql_context, snapshot):
+        selector = infer_pipeline_selector(graphql_context, "asset_lineage_pipeline")
         result = execute_dagster_graphql(
             graphql_context,
             LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": single_selector, "mode": "default"}},
+            variables={"executionParams": {"selector": selector, "mode": "default"}},
         )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-        single_run_id = result.data["launchPipelineExecution"]["run"]["runId"]
-
-        result = execute_dagster_graphql(
-            graphql_context,
-            LAUNCH_PIPELINE_EXECUTION_MUTATION,
-            variables={"executionParams": {"selector": multi_selector, "mode": "default"}},
-        )
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
 
         graphql_context.instance.run_launcher.join()
 
-        multi_run_id = result.data["launchPipelineExecution"]["run"]["runId"]
-
         result = execute_dagster_graphql(
-            graphql_context, GET_ASSET_RUNS, variables={"assetKey": {"path": ["a"]}}
+            graphql_context,
+            GET_ASSET_MATERIALIZATION,
+            variables={"assetKey": {"path": ["b"]}},
         )
         assert result.data
-        fetched_runs = [run["runId"] for run in result.data["assetOrError"]["runs"]]
-        assert len(fetched_runs) == 2
-        assert multi_run_id in fetched_runs
-        assert single_run_id in fetched_runs
+        snapshot.assert_match(result.data)
+
+    def test_get_partitioned_asset_key_lineage(self, graphql_context, snapshot):
+        selector = infer_pipeline_selector(graphql_context, "partitioned_asset_lineage_pipeline")
+        result = execute_dagster_graphql(
+            graphql_context,
+            LAUNCH_PIPELINE_EXECUTION_MUTATION,
+            variables={"executionParams": {"selector": selector, "mode": "default"}},
+        )
+        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
+
+        graphql_context.instance.run_launcher.join()
+
+        result = execute_dagster_graphql(
+            graphql_context,
+            GET_ASSET_MATERIALIZATION,
+            variables={"assetKey": {"path": ["b"]}},
+        )
+        assert result.data
+        snapshot.assert_match(result.data)
+
+    def test_asset_wipe(self, graphql_context):
+        _create_run(graphql_context, "single_asset_pipeline")
+        _create_run(graphql_context, "multi_asset_pipeline")
+
+        asset_keys = graphql_context.instance.all_asset_keys()
+        assert AssetKey("a") in asset_keys
+
+        result = execute_dagster_graphql(
+            graphql_context, WIPE_ASSETS, variables={"assetKeys": [{"path": ["a"]}]}
+        )
+
+        assert result.data
+        assert result.data["wipeAssets"]
+        assert result.data["wipeAssets"]["__typename"] == "AssetWipeSuccess"
+
+        asset_keys = graphql_context.instance.all_asset_keys()
+        assert AssetKey("a") not in asset_keys
+
+    def test_asset_tags(self, graphql_context, snapshot):
+        _create_run(graphql_context, "asset_tag_pipeline")
+        result = execute_dagster_graphql(
+            graphql_context, GET_ASSET_MATERIALIZATION, variables={"assetKey": {"path": ["a"]}}
+        )
+        assert result.data
+        assert result.data["assetOrError"]
+        assert result.data["assetOrError"]["tags"]
+        snapshot.assert_match(result.data)
+
+    def test_asset_asof_timestamp(self, graphql_context):
+        _create_run(graphql_context, "asset_tag_pipeline")
+        result = execute_dagster_graphql(
+            graphql_context,
+            GET_ASSET_MATERIALIZATION_TIMESTAMP,
+            variables={"assetKey": {"path": ["a"]}},
+        )
+        assert result.data
+        assert result.data["assetOrError"]
+        materializations = result.data["assetOrError"]["assetMaterializations"]
+        assert len(materializations) == 1
+        first_timestamp = int(materializations[0]["materializationEvent"]["timestamp"])
+
+        as_of_timestamp = first_timestamp + 1
+
+        time.sleep(1.1)
+        _create_run(graphql_context, "asset_tag_pipeline")
+        result = execute_dagster_graphql(
+            graphql_context,
+            GET_ASSET_MATERIALIZATION_TIMESTAMP,
+            variables={"assetKey": {"path": ["a"]}},
+        )
+        assert result.data
+        assert result.data["assetOrError"]
+        materializations = result.data["assetOrError"]["assetMaterializations"]
+        assert len(materializations) == 2
+        second_timestamp = int(materializations[0]["materializationEvent"]["timestamp"])
+
+        assert second_timestamp > as_of_timestamp
+
+        result = execute_dagster_graphql(
+            graphql_context,
+            GET_ASSET_MATERIALIZATION_TIMESTAMP,
+            variables={"assetKey": {"path": ["a"]}, "asOf": as_of_timestamp},
+        )
+        assert result.data
+        assert result.data["assetOrError"]
+        materializations = result.data["assetOrError"]["assetMaterializations"]
+        assert len(materializations) == 1
+        assert first_timestamp == int(materializations[0]["materializationEvent"]["timestamp"])
