@@ -6,13 +6,13 @@ from dagster_graphql.client.query import (
 from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
 
 from .graphql_context_test_suite import ExecutingGraphQLContextTestMatrix
-from .setup import csv_hello_world_solids_config, csv_hello_world_solids_config_fs_storage
+from .setup import csv_hello_world_solids_config
 
 RUN_QUERY = """
 query RunQuery($runId: ID!) {
   pipelineRunOrError(runId: $runId) {
     __typename
-    ... on PipelineRun {
+    ... on Run {
         status
       }
     }
@@ -30,16 +30,14 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
+                    "runConfigData": csv_hello_world_solids_config(),
                     "executionMetadata": {"runId": run_id},
                     "mode": "default",
                 }
             },
         )
 
-        assert (
-            result_one.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-        )
+        assert result_one.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
 
         result_one.data["launchPipelineExecution"]["run"]["runId"] = "<runId dummy value>"
         result_one.data["launchPipelineExecution"]["run"][
@@ -57,7 +55,7 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": csv_hello_world_solids_config_fs_storage(),
+                    "runConfigData": csv_hello_world_solids_config(),
                     "executionMetadata": {
                         "runId": new_run_id,
                         "rootRunId": run_id,
@@ -69,7 +67,7 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
         )
 
         query_result = result_two.data["launchPipelineReexecution"]
-        assert query_result["__typename"] == "LaunchPipelineRunSuccess"
+        assert query_result["__typename"] == "LaunchRunSuccess"
         assert query_result["run"]["rootRunId"] == run_id
         assert query_result["run"]["parentRunId"] == run_id
 
@@ -89,9 +87,7 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
             },
         )
 
-        assert (
-            result_one.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-        )
+        assert result_one.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
 
         result_one.data["launchPipelineExecution"]["run"]["runId"] = "<runId dummy value>"
         result_one.data["launchPipelineExecution"]["run"][
@@ -121,7 +117,7 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
         )
 
         query_result = result_two.data["launchPipelineReexecution"]
-        assert query_result["__typename"] == "LaunchPipelineRunSuccess"
+        assert query_result["__typename"] == "LaunchRunSuccess"
         assert query_result["run"]["rootRunId"] == run_id
         assert query_result["run"]["parentRunId"] == run_id
 
@@ -134,22 +130,21 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": {"storage": {"filesystem": {}}},
                     "executionMetadata": {"runId": run_id},
                     "mode": "default",
                 }
             },
         )
 
-        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchPipelineRunSuccess"
-        assert result.data["launchPipelineExecution"]["run"]["status"] == "NOT_STARTED"
+        assert result.data["launchPipelineExecution"]["__typename"] == "LaunchRunSuccess"
+        assert result.data["launchPipelineExecution"]["run"]["status"] == "STARTING"
 
         graphql_context.instance.run_launcher.join()
 
         result = execute_dagster_graphql(
             context=graphql_context, query=RUN_QUERY, variables={"runId": run_id}
         )
-        assert result.data["pipelineRunOrError"]["__typename"] == "PipelineRun"
+        assert result.data["pipelineRunOrError"]["__typename"] == "Run"
         assert result.data["pipelineRunOrError"]["status"] == "SUCCESS"
 
         # reexecution
@@ -160,7 +155,6 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
             variables={
                 "executionParams": {
                     "selector": selector,
-                    "runConfigData": {"storage": {"filesystem": {}}},
                     "executionMetadata": {
                         "runId": new_run_id,
                         "rootRunId": run_id,
@@ -170,12 +164,12 @@ class TestReexecution(ExecutingGraphQLContextTestMatrix):
                 }
             },
         )
-        assert result.data["launchPipelineReexecution"]["__typename"] == "LaunchPipelineRunSuccess"
+        assert result.data["launchPipelineReexecution"]["__typename"] == "LaunchRunSuccess"
 
         graphql_context.instance.run_launcher.join()
 
         result = execute_dagster_graphql(
             context=graphql_context, query=RUN_QUERY, variables={"runId": new_run_id}
         )
-        assert result.data["pipelineRunOrError"]["__typename"] == "PipelineRun"
+        assert result.data["pipelineRunOrError"]["__typename"] == "Run"
         assert result.data["pipelineRunOrError"]["status"] == "SUCCESS"
