@@ -104,7 +104,7 @@ ALL_RUNS_QUERY = """
 
 
 FILTERED_RUN_QUERY = """
-query PipelineRunsRootQuery($filter: PipelineRunsFilter!) {
+query PipelineRunsRootQuery($filter: RunsFilter!) {
   pipelineRunsOrError(filter: $filter) {
     ... on PipelineRuns {
       results {
@@ -116,7 +116,7 @@ query PipelineRunsRootQuery($filter: PipelineRunsFilter!) {
 """
 
 FILTERED_RUN_COUNT_QUERY = """
-query PipelineRunsRootQuery($filter: PipelineRunsFilter!) {
+query PipelineRunsRootQuery($filter: RunsFilter!) {
   pipelineRunsOrError(filter: $filter) {
     ... on PipelineRuns {
       count
@@ -277,7 +277,7 @@ class TestGetRuns(ExecutingGraphQLContextTestMatrix):
         result = execute_dagster_graphql(
             read_context, DELETE_RUN_MUTATION, variables={"runId": run_id_two}
         )
-        assert result.data["deletePipelineRun"]["__typename"] == "PipelineRunNotFoundError"
+        assert result.data["deletePipelineRun"]["__typename"] == "RunNotFoundError"
 
 
 def get_repo_at_time_1():
@@ -612,6 +612,38 @@ def test_filtered_runs_multiple_statuses():
             assert run_id_3 in run_ids
 
 
+def test_filtered_runs_multiple_filters():
+    with instance_for_test() as instance:
+        repo = get_repo_at_time_1()
+
+        started_run_with_tags = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.STARTED, tags={"foo": "bar"}
+        )
+        failed_run_with_tags = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"), status=PipelineRunStatus.FAILURE, tags={"foo": "bar"}
+        )
+        started_run_without_tags = instance.create_run_for_pipeline(
+            repo.get_pipeline("foo_pipeline"),
+            status=PipelineRunStatus.STARTED,
+            tags={"baz": "boom"},
+        )
+
+        with define_out_of_process_context(__file__, "get_repo_at_time_1", instance) as context:
+            result = execute_dagster_graphql(
+                context,
+                FILTERED_RUN_QUERY,
+                variables={
+                    "filter": {"statuses": ["STARTED"], "tags": [{"key": "foo", "value": "bar"}]}
+                },
+            )
+            assert result.data
+            run_ids = [run["runId"] for run in result.data["pipelineRunsOrError"]["results"]]
+            assert len(run_ids) == 1
+            assert started_run_with_tags.run_id in run_ids
+            assert failed_run_with_tags.run_id not in run_ids
+            assert started_run_without_tags.run_id not in run_ids
+
+
 def test_filtered_runs_count():
     with instance_for_test() as instance:
         repo = get_repo_at_time_1()
@@ -651,14 +683,18 @@ def test_run_group():
             __file__, "get_repo_at_time_1", instance
         ) as context_at_time_1:
             result_one = execute_dagster_graphql(
-                context_at_time_1, RUN_GROUP_QUERY, variables={"runId": root_run_id},
+                context_at_time_1,
+                RUN_GROUP_QUERY,
+                variables={"runId": root_run_id},
             )
             assert result_one.data["runGroupOrError"]["__typename"] == "RunGroup"
 
             assert len(result_one.data["runGroupOrError"]["runs"]) == 4
 
             result_two = execute_dagster_graphql(
-                context_at_time_1, RUN_GROUP_QUERY, variables={"runId": runs[-1].run_id},
+                context_at_time_1,
+                RUN_GROUP_QUERY,
+                variables={"runId": runs[-1].run_id},
             )
             assert result_one.data["runGroupOrError"]["__typename"] == "RunGroup"
             assert len(result_two.data["runGroupOrError"]["runs"]) == 4
@@ -680,7 +716,9 @@ def test_run_group_not_found():
         ) as context_at_time_1:
 
             result = execute_dagster_graphql(
-                context_at_time_1, RUN_GROUP_QUERY, variables={"runId": "foo"},
+                context_at_time_1,
+                RUN_GROUP_QUERY,
+                variables={"runId": "foo"},
             )
             assert result.data
             assert result.data["runGroupOrError"]
