@@ -1,14 +1,13 @@
 import os
 
 import pendulum
-import yaml
 from dagster.core.definitions.reconstructable import ReconstructableRepository
 from dagster.core.host_representation import (
     ExternalRepositoryOrigin,
     InProcessRepositoryLocationOrigin,
 )
 from dagster.core.scheduler.job import JobState, JobStatus, JobType, ScheduleJobData
-from dagster.seven import create_pendulum_time
+from dagster.seven.compat.pendulum import create_pendulum_time
 from dagster_graphql.test.utils import (
     execute_dagster_graphql,
     infer_repository_selector,
@@ -89,8 +88,8 @@ query getSchedule($scheduleSelector: ScheduleSelector!, $ticksAfter: Float) {
 
 GET_UNLOADABLE_QUERY = """
 query getUnloadableSchedules {
-  unloadableJobStatesOrError(jobType: SCHEDULE) {
-    ... on JobStates {
+  unloadableInstigationStatesOrError(instigationType: SCHEDULE) {
+    ... on InstigationStates {
       results {
         id
         name
@@ -172,18 +171,17 @@ mutation(
 
 def default_execution_params():
     return {
-        "runConfigData": {"intermediate_storage": {"filesystem": None}},
         "selector": {"name": "no_config_pipeline", "solidSelection": None},
         "mode": "default",
     }
 
 
-def _get_unloadable_schedule_origin(job_name):
+def _get_unloadable_schedule_origin(name):
     working_directory = os.path.dirname(__file__)
     recon_repo = ReconstructableRepository.for_file(__file__, "doesnt_exist", working_directory)
     return ExternalRepositoryOrigin(
         InProcessRepositoryLocationOrigin(recon_repo), "fake_repository"
-    ).get_job_origin(job_name)
+    ).get_job_origin(name)
 
 
 def test_get_schedule_definitions_for_repository(graphql_context):
@@ -270,7 +268,7 @@ def test_get_single_schedule_definition(graphql_context):
 
     assert result.data["scheduleOrError"]["__typename"] == "Schedule"
     assert result.data["scheduleOrError"]["partitionSet"]
-    assert result.data["scheduleOrError"]["executionTimezone"] == pendulum.now().timezone.name
+    assert result.data["scheduleOrError"]["executionTimezone"] == "UTC"
 
     future_ticks = result.data["scheduleOrError"]["futureTicks"]
     assert future_ticks
@@ -357,11 +355,6 @@ def test_next_tick(graphql_context):
         assert tick["evaluationResult"]
         assert tick["evaluationResult"]["runRequests"]
         assert len(tick["evaluationResult"]["runRequests"]) == 1
-        assert tick["evaluationResult"]["runRequests"][0]["runConfigYaml"] == yaml.dump(
-            {"intermediate_storage": {"filesystem": {}}},
-            default_flow_style=False,
-            allow_unicode=True,
-        )
 
 
 def test_next_tick_bad_schedule(graphql_context):
@@ -434,5 +427,8 @@ def test_get_unloadable_job(graphql_context):
         )
 
     result = execute_dagster_graphql(graphql_context, GET_UNLOADABLE_QUERY)
-    assert len(result.data["unloadableJobStatesOrError"]["results"]) == 1
-    assert result.data["unloadableJobStatesOrError"]["results"][0]["name"] == "unloadable_running"
+    assert len(result.data["unloadableInstigationStatesOrError"]["results"]) == 1
+    assert (
+        result.data["unloadableInstigationStatesOrError"]["results"][0]["name"]
+        == "unloadable_running"
+    )
